[PATCH 3/6] exec: cleanup the count() function

From: Christoph Hellwig
Date: Mon Jun 15 2020 - 09:02:06 EST


Remove the max argument as it is hard wired to MAX_ARG_STRINGS, and
give the function a slightly less generic name.

Signed-off-by: Christoph Hellwig <hch@xxxxxx>
---
fs/exec.c | 10 +++++-----
1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/fs/exec.c b/fs/exec.c
index 94107eceda8a67..6e4d9d1ffa35fa 100644
--- a/fs/exec.c
+++ b/fs/exec.c
@@ -411,9 +411,9 @@ get_user_arg_ptr(const char __user *const __user *argv, int nr)
}

/*
* count() counts the number of strings in array ARGV.
*/
-static int count(const char __user *const __user *argv, int max)
+static int count_strings(const char __user *const __user *argv)
{
int i = 0;

@@ -427,7 +427,7 @@ static int count(const char __user *const __user *argv, int max)
if (IS_ERR(p))
return -EFAULT;

- if (i >= max)
+ if (i >= MAX_ARG_STRINGS)
return -E2BIG;
++i;

@@ -445,11 +445,11 @@ static int prepare_arg_pages(struct linux_binprm *bprm,
{
unsigned long limit, ptr_size;

- bprm->argc = count(argv, MAX_ARG_STRINGS);
+ bprm->argc = count_strings(argv);
if (bprm->argc < 0)
return bprm->argc;

- bprm->envc = count(envp, MAX_ARG_STRINGS);
+ bprm->envc = count_strings(envp);
if (bprm->envc < 0)
return bprm->envc;
@@ -411,9 +411,9 @@ get_user_arg_ptr(const char __user *const __user *argv, int nr)

/*
- * count() counts the number of strings in array ARGV.
+ * count_strings() counts the number of strings in array ARGV.
*/

--
2.26.2